@@ -54,7 +54,7 @@ class AgentBasePrivate : public QObject
     QString defaultReadyMessage() const
     {
       if ( mOnline )
-        return i18nc( "@info:status, application ready for work", "Ready" );
+        return i18nc( "@info:status Application ready for work", "Ready" );
       return i18nc( "@info:status", "Offline" );
     }
 
@@ -96,9 +96,13 @@ class AgentBasePrivate : public QObject
     void itemChanged( const Akonadi::Item &item, const QSet<QByteArray> &partIdentifiers );
     void itemMoved( const Akonadi::Item &, const Akonadi::Collection &source, const Akonadi::Collection &destination );
     void itemRemoved( const Akonadi::Item &item );
+    void itemLinked( const Akonadi::Item &item, const Akonadi::Collection &collection );
+    void itemUnlinked( const Akonadi::Item &item, const Akonadi::Collection &collection );
 
     void collectionAdded( const Akonadi::Collection &collection, const Akonadi::Collection &parent );
     void collectionChanged( const Akonadi::Collection &collection );
+    void collectionChanged( const Akonadi::Collection &collection, const QSet<QByteArray> &partIdentifiers );
+    void collectionMoved( const Akonadi::Collection &collection, const Akonadi::Collection &source, const Akonadi::Collection &destination );
     void collectionRemoved( const Akonadi::Collection &collection );
 };
 
