@@ -34,6 +34,7 @@
 
 #include "listbase.h"
 #include "person.h"
+#include "customproperties.h"
 
 namespace KCal {
 
@@ -233,7 +234,8 @@ class KCAL_EXPORT Attendee : private Person
 
       @param attendee the attendee to compare.
     */
-    bool operator==( const Attendee &attendee );
+    //KDE5: make const
+    bool operator==( const Attendee &attendee ); //krazy:exclude=operators
 
     /**
       Sets the delegate.
@@ -263,6 +265,26 @@ class KCAL_EXPORT Attendee : private Person
     */
     QString delegator() const;
 
+    /**
+      Adds a custom property. If the property already exists it will be overwritten.
+      @param xname is the name of the property.
+      @param xvalue is its value.
+      @since 4.4
+    */
+    void setCustomProperty( const QByteArray &xname, const QString &xvalue );
+
+    /**
+      Returns a reference to the CustomProperties object
+      @since 4.4
+    */
+    CustomProperties &customProperties();
+
+    /**
+      Returns a const reference to the CustomProperties object
+      @since 4.4
+    */
+    const CustomProperties &customProperties() const;
+
     /**
       Sets this attendee equal to @p attendee.
 
